/******************************************************************************
 Loading of external libraries/modules
 *****************************************************************************/
/* load external module 'Preferences.js' into the scope of 'foxfm
   --> prefix 'foxfm.' need to be used at function calls of this module */
var foxfm = {};
Components.utils.import("resource://modules/Preferences.js", foxfm);

/******************************************************************************
 Initialisation of the global variables
 *****************************************************************************/
/* global variables for preference handling */
var prefBranchOFMStrengthLevel = new foxfm.Preferences("foxfm.pref.ofm.strengthlevel.");
var prefBranchAbout = new foxfm.Preferences("foxfm.pref.about.");
var prefBranchOFMFunctionSettings = new foxfm.Preferences("foxfm.pref.ofm.");

/* globals of the extension */
var prefBranchAddOn = new foxfm.Preferences("foxfm.pref.");
var gMinInfoLvl = foxfm_getOFMInfoLevel();

/* global variable saving OFM strength level points */
var gStrengthPoints=new Array();

/* global variable saving OFM Team name of who is logged in */
var gTeamName;

/******************************************************************************
 MAIN load (executed only 1 time)
 *****************************************************************************/
function foxfm_load() 
{
	gStrengthPoints = foxfm_getOFMStrengthLevel();
	window.addEventListener('DOMContentLoaded', foxfm_run, true);
	window.addEventListener('popupshowing', foxfm_initPopupMenu, true);

	infoMessage(1, "loaded");
}

function foxfm_run(event) 
{
	try 
	{
		var doc = event.originalTarget;
		
		if (doc.nodeType != doc.DOCUMENT_NODE) 
		{
			doc = doc.ownerDocument;
		}		
		if (!doc || doc == null || doc.location == null || !foxfm_isOFMDomain(doc.location.href)) 
		{
			return;
		}
		
		infoMessage(1, "run");
		
		/* Call all addon function ones */
		if (foxfm_isOFMDomain(doc.location.href))
		{
			foxfm_addJavaScript(doc, "chrome://foxfm/content/resources/js/foxfm_common.js");
		
			foxfm_arm(doc);
			foxfm_bank(doc);
			foxfm_stadium(doc);
			foxfm_team(doc);
			foxfm_team_training(doc);
			foxfm_tm_pros(doc);
			foxfm_tm_amas(doc);
		}
		
		/* Get the name of the current OFM team from the header of the OFM 
		   page located after the string "Team:" */
		if (foxfm_isOFMDomainHeader(doc.location.href))
		{
			/* Get all the tables of the current doc(ument) */
			var tables = doc.getElementsByTagName("table");
			/* Search the tables */
			var results = findTableByRegExp(tables, "Team:");
			/* There is to be only one result expected for the search term */
			if (results.length == 1)
			{
				/* The name of the team is usually encapsulated in an anchor */
				var anchors = tables[results[0]["table"]].rows[results[0]["row"]].cells[results[0]["cell"]].getElementsByTagName("a");
				if (anchors.length == 1)
				{
					gTeamName = anchors[0].innerHTML;
					infoMessage(1, "Teamname: " + "'" + gTeamName + "'");
				}
				else
				{
					infoMessage(0, "Could not clearly determine the name of the team.");
				}
			}
			else
			{
				infoMessage(0, "Could not clearly determine the name of the team.");
			}			
		}
	} catch (e) {
		exceptionHandler(e);
	}
}

function foxfm_initPopupMenu(event) {
    try {         
		if (event.target.id != "contentAreaContextMenu") 
		{
			return;
		}

		var contextMenu = document.getElementById("foxfm_contextMain");

		contextMenu.setAttribute("hidden",!foxfm_isOFMDomain(window._content.document.location.href));
		return;
    } catch (e){
        exceptionHandler(e);
    }
}

// start foxfm
foxfm_load();